from enums.Extension import Extension
from enums.Column import Column
from enums.Args import Args
from enums.NavigationalStatus import NavigationalStatus
from pathlib import Path
from polars import read_csv
from polars import col
from polars import collect_all

class Processing(object):
    def __init__(self, path):
        # Transform the given path in a list to handle string, list, tuple or set
        pathList = list(path)

        # Handle the lazyFrames for processing
        self.lazyFrames = list()

        # Handle the names for the saving
        self.names = list()

        for path in pathList:
            if (isinstance(path, str)):
                path = Path(path)
                for extension in Extension:
                    if (path.is_file() and path.suffix == extension.value):
                        self.names.append(path.name)
                        self.lazyFrames.append(read_csv(path, ignore_errors = Args.IGNORE_ERRORS.value, sep = Args.SEPARATOR.value))
                    elif (path.is_dir()):
                        for file in path.glob(Args.WILDCARD.value + extension.value):
                            self.names.append(file.name)
                            self.lazyFrames.append(read_csv(file, ignore_errors = Args.IGNORE_ERRORS.value, sep = Args.SEPARATOR.value))
                    else:
                        print("The path \"" + str(path) + "\" is not a valid path. It will not be processed.")
            else:
                print("The path \"" + str(path) + "\" is not a string. It will not be processed.")

    def sort(self, column):
        for i in range(len(self.lazyFrames)):
            self.lazyFrames[i] = self.lazyFrames[i].sort(column)

    def route(self):
        self.sort(Column.MMSI.value)
        for i in range (len(self.lazyFrames)):
            self.lazyFrames[i] = self.lazyFrames[i].filter(

            # The first row can't be shifted since there is no data to compare,
            # so include the first row in the filter
            (col(Column.NAVIGATION_STATUS.value).is_first()) |

            # See if the MMSI changed between current and next row
            (col(Column.MMSI.value) != col(Column.MMSI.value).shift()) |

            # See if the navigation status changed between current and next row
            (col(Column.NAVIGATION_STATUS.value) != col(Column.NAVIGATION_STATUS.value).shift()))
        self.sort(Column.COMPLETE_SYS_DATE.value)

    def save(self, path):
        for i in range(len(self.lazyFrames)):
            self.lazyFrames[i].to_csv(path + self.names[i], sep = ";")

l = ["C:\\Users\\jerem\\Documents\\FAC\\M1\\TPE\\ais-operations\\ressources\\BD-AIS\\FichiersCSV-Exemples"]
test = Processing(l)
test.route()
test.save("C:\\Users\\jerem\\Documents\\FAC\\M1\\TPE\\ais-operations\\resources\\")